# ==============================================================================================
# NAME: CreateObject_AdoNet.ps1
# 
# AUTHOR: ed wilson , Microsoft 
# DATE  : 9/17/2008
# 
# COMMENT: Queries Excel spread sheet using ado.net
# uses ado.net from .NET framework to query an
# excel spread sheet. using the dot net framework
# ado classes we do not need to have Excel installed
# on the computer.
# just as in classic ado we need to use the Jet oledb provider
# and specify extended properties for excel.
# we then need to create an instance of the 
# System.Data.OleDb.OleDbConnection and 
# System.Data.OleDb.OleDbCommand classes. 
# We then use the ExecuteReader method to return a DataReader
# object. This object is an instance of the System.Data.OleDb.OleDbDataReader class.
# The first thing we need to do with the DataReader is to use
# the read method. We use while to loop through the DataReader.
# Each column can be indexed as seen here: $DataReader[2].Tostring() 
# this picks up the third column. $DataReader[0].Tostring() is first one 
#
# -------------------------------------------------------------------------------------------
Param([switch]$verbose)

Function TestPath($FilePath)
{
 If(Test-Path -path $FilePath)
   {
    if($verbose) { "$filePath found" }
  } #end if
 ELSE
  {
   Write-Host -foregroundcolor red "$filePath not found."
   Exit
  } #end else
} #end TestPath

Function SetConnectionString()
{
 $strFileName = $FilePath
 $strSheetName = 'Excel$'
 $strProvider = "Provider=Microsoft.Jet.OLEDB.4.0"
 $strDataSource = "Data Source = $strFileName"
 $strExtend = "Extended Properties=Excel 8.0"
 $strQuery = "Select * from [$strSheetName]"
 NewAdoConnection
} #end SetConnectionString

Function NewAdoConnection()
{
 $Script:objConn = New-Object System.Data.OleDb.OleDbConnection("$strProvider;$strDataSource;$strExtend")
 $sqlCommand = New-Object System.Data.OleDb.OleDbCommand($strQuery)
 $sqlCommand.Connection = $objConn
 $Script:objConn.open()
 $Script:DataReader = $sqlCommand.ExecuteReader()
} #end NewAdoConnection

Function ReadData()
{
 While($Script:DataReader.read())
 {
  $Script:Name = $Script:DataReader[0].Tostring() 
  $Script:Path = $Script:DataReader[1].Tostring() 
  $Script:Class = $Script:DataReader[2].Tostring() 
  CreateObject
 } #end while
} #end ReadData

Function CreateObject()
{
 If($verbose)
  {
   "Creating $Script:Class $Script:Name,$Script:Path"
  } #end if verbose
 $adsi = [adsi]"LDAP://$Script:path"
 $de = $adsi.Create($Script:class,$Script:name)
 $de.SetInfo()
} #end CreateObject

Function CloseAdoConnection()
{  
 $Script:dataReader.close()
 $Script:objConn.close()
}

# *** Entry Point ***
$FilePath = "C:\BestPractices\excel.xls"
TestPath($FilePath)
SetConnectionString
ReadData
CloseAdoConnection
